package com.game.Metagame
{
	import org.flixel.*;

	public class Player extends FlxSprite
	{
		[Embed(source="../../../data/robot.png")] private var ImgPlayer:Class;
		private var _jumpTime:Number;
		private var _jumpDuration:Number;
		private var _jumping:Boolean;
		private var _up:Boolean;
		private var _down:Boolean;
		private var _gibs:FlxEmitter; //hooray! maybe use more than one, for more cinematic deaths.
		private var _thrust:FlxPoint;
		private var _gravity:Number; //should we have gravity be global or per-object?
		private var _groundDrag:Number;
		private var _airDrag:Number;
		private var _airThrustMultiplier:Number;
		private var _crouchThrustMultiplier:Number;
		
		public function Player(X:int,Y:int)
		{
			super(X,Y);
			loadGraphic(ImgPlayer,true,true,32,32);
			
			//bounding box tweaks
			width = 14;
			height = 25;
			offset.x = 9;
			offset.y = 2;
			
			//basic player physics
			_thrust = new FlxPoint(600,1000); //running and jump input thrust
			_jumpDuration = 15
			_airThrustMultiplier = 0.5;
			_crouchThrustMultiplier = 0.3;
			_groundDrag = 0.85;
			_airDrag = 0.95;
			_gravity = 200
			maxVelocity.x = 100;
			maxVelocity.y = 900;
			
			//animations
			addAnimation("idle", [0]); //SECOND FRAME LOOKS PFF LAME, WILL NEED EITHER 3 FRAMES OR NO ANIM
			addAnimation("run", [2, 3, 4, 5, 6, 7, 8], 5);
			addAnimation("jumpup", [3,4],2,false);
			addAnimation("jumpdown", [6,7],2,false);
			addAnimation("crouch", [10]);
		}
		
		override public function update():void
		{
			//MOVEMENT
			
			//drag
			velocity.x *= onFloor?_groundDrag:_airDrag;
			velocity.y *= _airDrag;
			
			acceleration.x = 0;
			acceleration.y = _gravity;
			var thrustDir:int = int(FlxG.keys.RIGHT)-int(FlxG.keys.LEFT); //1 is right, -1 is left.
			if (thrustDir != 0)
			{
				facing = thrustDir>0?RIGHT:LEFT;
				acceleration.x += thrustDir*_thrust.x;
				if (_jumping)
					acceleration.x *= _airThrustMultiplier; //less thrust in the air
				if(FlxG.keys.DOWN)
					acceleration.x *= _crouchThrustMultiplier; //less thrust while crouching
			}
			if(FlxG.keys.justPressed("UP") && onFloor)
			{
				acceleration.y -= _thrust.y;
				_jumpTime = 1; //after this timer elapses (gets to zero), the player can no longer control the vertical of the jump
				_jumping = true;
			}
			if (_jumping) //tick down and such
			{
				_jumpTime -= 1/_jumpDuration;
				if (FlxG.keys.justReleased("UP") || _jumpTime < 0)
					_jumping = false;
			}
			if (FlxG.keys.UP && _jumping)
			{
				acceleration.y -= _thrust.y*_jumpTime^2; //this is unphysical. Its purpose is to allow variable height jumps.
			}
			//TODO: Aiming
			
			//ANIMATION
			if(FlxG.keys.DOWN)
			{
				play("crouch");
			}
			else if(velocity.y < 0)
			{
				play("jumpup");
			}
			else if(velocity.y > 0)
			{
				play("jumpdown");
			}
			else if(thrustDir == 0)
			{
				play("idle");
			}
			else
			{
				play("run");
			}
			//interaction
			//if(FlxG.keys.justPressed("C"))
			//{
				//do interaction stuff here
			//}
			//UPDATE POSITION AND ANIMATION
			super.update();
		}
		
		override public function hitBottom(Contact:FlxObject,Velocity:Number):void
		{
			//if(velocity.y > 50)
				//FlxG.play(SndLand); ---------------------------------------------------ADD LANDING SOUND
			onFloor = true;
			_jumping = false;
			_jumpTime = 0;
			return super.hitBottom(Contact,Velocity);
		}
	}
}
